pub fn hash_file_checksum(
path: &Path,
checksum_type: ChecksumType,
) -> Result<String>Expand description
Compute a hex-encoded checksum of a file using the specified algorithm.
pub fn hash_file_checksum(
path: &Path,
checksum_type: ChecksumType,
) -> Result<String>Compute a hex-encoded checksum of a file using the specified algorithm.