pub struct MerkleTree {
pub chunk_size: u64,
pub file_size: u64,
pub root: Hash,
pub leaves: Vec<ChunkHash>,
}Expand description
BLAKE3 Merkle tree over fixed-size file chunks.
Fields
chunk_size: u64Fixed chunk size used for this tree
file_size: u64Total file size at tree construction time
root: HashRoot hash computed from all leaf hashes
leaves: Vec<ChunkHash>Per-chunk hashes with offset metadata
Implementations
Sourceimpl MerkleTree
impl MerkleTree
Sourcepub fn from_file(
path: &Path,
chunk_size: u64,
compute_mode: ComputeMode,
) -> Result<Self>
pub fn from_file( path: &Path, chunk_size: u64, compute_mode: ComputeMode, ) -> Result<Self>
Build a Merkle tree by hashing a file in fixed-size chunks.
Sourcepub fn diff(source: &MerkleTree, target: &MerkleTree) -> Vec<DirtyRange>
pub fn diff(source: &MerkleTree, target: &MerkleTree) -> Vec<DirtyRange>
Compare two Merkle trees and return ranges that differ. Adjacent dirty chunks are merged into contiguous ranges.
Sourcepub fn to_signature(&self) -> MerkleSignature
pub fn to_signature(&self) -> MerkleSignature
Convert to a serializable signature.
Sourcepub fn from_signature(sig: &MerkleSignature) -> Option<Self>
pub fn from_signature(sig: &MerkleSignature) -> Option<Self>
Reconstruct a MerkleTree from a stored signature.